﻿using Hotline.Share.Dtos.Order;
using Hotline.Share.Enums.Order;
using MapsterMapper;
using MediatR;
using Sharing.DaoShu110.Dtos;
using Sharing.DataExchange;
using Sharing.Enterprise;
using Sharing.Notifications.DataExchange;
using Sharing.Notifications.Enterprise;
using Sharing.Notifications.HuiJu;
using Sharing.Notifications.XieTong;
using Sharing.Orders;
using Sharing.Province.Dtos.Extend;
using Sharing.Province.Dtos.HuiJu.Send;
using Sharing.Province.Extend;
using Sharing.Province.HuiJu.Send;
using Sharing.Province.Other;
using Sharing.Province.XieTong.Receive;
using Sharing.Province.XieTong.Send;
using Sharing.Share.Dtos.DataExchange;
using Sharing.Share.Enums.DaoShu110;
using XF.Domain.Dependency;
using XF.Domain.Repository;

namespace Sharing.Api
{
    /// <summary>
    /// 
    /// </summary>
    public class ProvinceService : IProvinceService, IScopeDependency
    {

        #region 注入
        private readonly IRepository<SubmitCaseInfo> _submitCaseInfoRepository;
        private readonly IMapper _mapper;
        private readonly IMediator _mediator;
        private readonly IRepository<PoliceSendChainAlarmDs> _policeSendChainAlarmDsRepository;
        private readonly IRepository<SubmitVisitInfo> _submitVisitInfoRepository;
        private readonly IRepository<WaitingPushData> _waitingPushDataRepository;
        private readonly IRepository<SubmitCaseProcess> _submitCaseProcessRepository;
        private readonly IRepository<PoliceSendChainDealDs> _policeSendChainDealDsRepository;
        private readonly IRepository<SubmitCaseResult> _submitCaseResultRepository;
        private readonly IRepository<ReceiveCaseExtends> _receiveCaseExtendsRepository;
        private readonly IRepository<FormEnvironMent> _formEnvironMentRepository;
        private readonly IRepository<FormTraffic> _formTrafficRepository;
        private readonly IRepository<FormExpressWay> _formExpressWayRepository;
        private readonly IRepository<FormMedical> _formMedicalRepository;
        private readonly IRepository<FormNetWorktec> _formNetWorktecRepository;
        private readonly IRepository<FormPost> _formPostRepository;
        private readonly IRepository<FormReturnexChange> _formReturnexChangeRepository;
        private readonly IRepository<FormShamPub> _formShamPubRepository;
        private readonly IRepository<FormTaxationComplaint> _formTaxationComplaintRepository;
        private readonly IRepository<FormTaxationConsulting> _formTaxationConsultingRepository;
        private readonly IRepository<FormMarket> _formMarketRepository;
        private readonly IRepository<DataWorkOrderSend> _dataWorkOrderSendRepository;
        private readonly IRepository<CityDataSend> _cityDataSendRepository;
        private readonly IRepository<SendCaseInfo> _sendCaseInfoRepository;
        private readonly IRepository<GetCaseMaterialInfo> _getCaseMaterialInfoRepository;

        /// <summary>
        /// 注入
        /// </summary>
        /// <param name="submitCaseInfoRepository"></param>
        /// <param name="mapper"></param>
        /// <param name="mediator"></param>
        /// <param name="policeSendChainAlarmDsRepository"></param>
        /// <param name="submitVisitInfoRepository"></param>
        /// <param name="waitingPushDataRepository"></param>
        /// <param name="submitCaseProcessRepository"></param>
        /// <param name="policeSendChainDealDsRepository"></param>
        /// <param name="submitCaseResultRepository"></param>
        /// <param name="receiveCaseExtendsRepository"></param>
        /// <param name="formEnvironMentRepository"></param>
        /// <param name="formTrafficRepository"></param>
        /// <param name="formExpressWayRepository"></param>
        /// <param name="formMedicalRepository"></param>
        /// <param name="formNetWorktecRepository"></param>
        /// <param name="formPostRepository"></param>
        /// <param name="formReturnexChangeRepository"></param>
        /// <param name="formShamPubRepository"></param>
        /// <param name="formTaxationComplaintRepository"></param>
        /// <param name="formTaxationConsultingRepository"></param>
        /// <param name="formMarketRepository"></param>
        /// <param name="dataWorkOrderSendRepository"></param>
        /// <param name="cityDataSendRepository"></param>
        /// <param name="sendCaseInfoRepository"></param>
        /// <param name="getCaseMaterialInfoRepository"></param>
        public ProvinceService(IRepository<SubmitCaseInfo> submitCaseInfoRepository,
          IMapper mapper,
          IMediator mediator,
          IRepository<PoliceSendChainAlarmDs> policeSendChainAlarmDsRepository,
          IRepository<SubmitVisitInfo> submitVisitInfoRepository,
          IRepository<WaitingPushData> waitingPushDataRepository,
          IRepository<SubmitCaseProcess> submitCaseProcessRepository,
          IRepository<PoliceSendChainDealDs> policeSendChainDealDsRepository,
          IRepository<SubmitCaseResult> submitCaseResultRepository,
          IRepository<ReceiveCaseExtends> receiveCaseExtendsRepository,
          IRepository<FormEnvironMent> formEnvironMentRepository,
          IRepository<FormTraffic> formTrafficRepository,
          IRepository<FormExpressWay> formExpressWayRepository,
          IRepository<FormMedical> formMedicalRepository,
          IRepository<FormNetWorktec> formNetWorktecRepository,
          IRepository<FormPost> formPostRepository,
          IRepository<FormReturnexChange> formReturnexChangeRepository,
          IRepository<FormShamPub> formShamPubRepository,
          IRepository<FormTaxationComplaint> formTaxationComplaintRepository,
          IRepository<FormTaxationConsulting> formTaxationConsultingRepository,
          IRepository<FormMarket> formMarketRepository,
          IRepository<DataWorkOrderSend> dataWorkOrderSendRepository,
          IRepository<CityDataSend> cityDataSendRepository,
          IRepository<SendCaseInfo> sendCaseInfoRepository,
          IRepository<GetCaseMaterialInfo> getCaseMaterialInfoRepository)
        {
            _submitCaseInfoRepository = submitCaseInfoRepository;
            _mapper = mapper;
            _mediator = mediator;
            _policeSendChainAlarmDsRepository = policeSendChainAlarmDsRepository;
            _submitVisitInfoRepository = submitVisitInfoRepository;
            _waitingPushDataRepository = waitingPushDataRepository;
            _submitCaseProcessRepository = submitCaseProcessRepository;
            _policeSendChainDealDsRepository = policeSendChainDealDsRepository;
            _submitCaseResultRepository = submitCaseResultRepository;
            _receiveCaseExtendsRepository = receiveCaseExtendsRepository;
            _formEnvironMentRepository = formEnvironMentRepository;
            _formTrafficRepository = formTrafficRepository;
            _formExpressWayRepository = formExpressWayRepository;
            _formMedicalRepository = formMedicalRepository;
            _formNetWorktecRepository = formNetWorktecRepository;
            _formPostRepository = formPostRepository;
            _formReturnexChangeRepository = formReturnexChangeRepository;
            _formShamPubRepository = formShamPubRepository;
            _formTaxationComplaintRepository = formTaxationComplaintRepository;
            _formTaxationConsultingRepository = formTaxationConsultingRepository;
            _formMarketRepository = formMarketRepository;
            _dataWorkOrderSendRepository = dataWorkOrderSendRepository;
            _cityDataSendRepository = cityDataSendRepository;
            _sendCaseInfoRepository = sendCaseInfoRepository;
            _getCaseMaterialInfoRepository = getCaseMaterialInfoRepository;
        }
        #endregion

        /// <summary>
        /// 工单创建数据处理
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        public async Task<SubmitCaseInfo> InitData(OrderDto dto)
        {
            var submitCaseInfo = _mapper.Map<SubmitCaseInfo>(dto);

            //处理性别
            submitCaseInfo.AppLicantSex = dto.FromGender switch
            {
                EGender.Female => "0",
                EGender.Male => "1",
                EGender.Unknown => "2",
                _ => "2",
            };

            //处理证件类型
            submitCaseInfo.CertifiCateType = dto.LicenceTypeCode switch
            {
                "10" => "10",
                "40" => "20",
                "55" => "30",
                "57" => "40",
                _ => "50",
            };

            //处理紧急程度
            switch (dto.EmergencyLevel)
            {
                case EEmergencyLevel.QuiteEmergency:
                    submitCaseInfo.CaseIsUrgent = "10";
                    break;
                case EEmergencyLevel.Emergency:
                    submitCaseInfo.CaseIsUrgent = "20";
                    break;
                default:
                    submitCaseInfo.CaseIsUrgent = "30";
                    break;
            }

            //处理诉求类型
            switch (submitCaseInfo.CaseType)
            {
                case "10":
                case "15":
                case "20":
                case "25":
                case "30":
                case "35":
                    break;
                default:
                    submitCaseInfo.CaseType = "40";
                    break;
            }
            var data = await _submitCaseInfoRepository.GetAsync(p => p.CaseSerial == dto.ProvinceNo);
            if (data != null)
                submitCaseInfo.CliengGuid = data.CliengGuid;
            else
                submitCaseInfo.CliengGuid = Guid.NewGuid().ToString();

            submitCaseInfo.Id = await _submitCaseInfoRepository.AddAsync(submitCaseInfo);

            return submitCaseInfo;
        }

        /// <summary>
        /// 派单是判断需要往第三方推送数据
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        public async Task OrderDispatch(OrderFlowDto dto)
        {
            #region 第三方提交数据
            if (dto.WorkflowTrace.NextHandlers != null && dto.WorkflowTrace.NextHandlers.Count > 0)
            {
                foreach (var item in dto.WorkflowTrace.NextHandlers)
                {
                    if (!string.IsNullOrEmpty(item.Value))
                    {
                        //需要判断是否需要往110推送
                        if (item.Value == "市公安局110")
                            //写入110本地数据库
                            await InitPoliceSendChainAlarmDs(dto.Order);

                        //需要判断是否需要往宜宾等地市州推送数据
                        if (item.Value == "泸州12345")
                            //市州数据提交
                            await InitCityDataYB(dto.Order);

                        //需要判断是否需要往企业专班提交数据
                        if (item.Value == "企业服务专班")
                            //企业专班提交数据
                            await InitEnterpriseData(dto.Order);

                        //是否向省上派单
                        if (item.Value == "省12345平台")
                            await SendCaseInfo(dto.Order);
                    }
                }
            }
            #endregion
        }

        /// <summary>
        /// 服务工单回访评价
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        public async Task SubmitVisitInfo(PublishVisitDto dto)
        {
            var data = _mapper.Map<SubmitVisitInfo>(dto);
            switch (dto.VisitType)
            {
                case EVisitType.ArtificialVisit:
                    data.VisitType = "DH";
                    break;
                case EVisitType.SmsVisit:
                    data.VisitType = "DX";
                    break;
                case EVisitType.WebVisit:
                    data.VisitType = "WZ";
                    break;
                case EVisitType.WeChatVisit:
                    data.VisitType = "WX";
                    break;
                case EVisitType.AppVisit:
                    data.VisitType = "AP";
                    break;
                default:
                    break;
            }
            data.CliengGuid = Guid.NewGuid().ToString();
            //将上报信息写入本地库
            data.Id = await _submitVisitInfoRepository.AddAsync(data);

            //将待推送数据写入待推送表
            WaitingPushData pushData = new()
            {
                ServiceInterface = "SubmitVisitInfo",
                Data = System.Text.Json.JsonSerializer.Serialize(data),
                Priority = 0,
                PushUrl = "submit_visit_info",
                Method = HttpMethods.Post,
                SyncID = data.Id
            };
            await _waitingPushDataRepository.AddAsync(pushData);

            //组装110数据
            if (dto.Order.Source == ESource.Police110)
            {
                var checkData = await _policeSendChainDealDsRepository.GetAsync(p => p.AlarmReceiptNumber == dto.Order.ExternalId && p.DisposalType == (int)EDisposalType.Visit);
                if (checkData == null)
                {
                    checkData = new()
                    {
                        AlarmReceiptNumber = dto?.Order?.ExternalId,
                        RevisitTime = dto.VisitTime,
                        CheckingContent = dto.VisitRemark,
                        VisitContent = dto.VisitRemark,
                        VisitResult = dto.SubjectResultSatifyCode + "",
                        DisposalType = 3
                    };
                    await _policeSendChainDealDsRepository.AddAsync(checkData);
                }
                else
                {
                    checkData.AlarmReceiptNumber = dto?.Order?.ExternalId;
                    checkData.RevisitTime = dto.VisitTime;
                    checkData.CheckingContent = dto.VisitRemark;
                    checkData.VisitContent = dto.VisitRemark;
                    checkData.VisitResult = dto.SubjectResultSatifyCode + "";
                    await _policeSendChainDealDsRepository.UpdateAsync(checkData);
                }

            }

            //处理附件
            await FileData(new List<Hotline.Share.Dtos.File.FileDto>(), data.CaseSerial, data.CliengGuid, data.AreaCode);
        }

        /// <summary>
        /// 服务工单处理
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        public async Task SubmitCaseProcess(OrderFlowDto dto)
        {
            var data = _mapper.Map<SubmitCaseProcess>(dto);

            data.TacheName = "70:" + data.DeptName;
            //将上报信息写入本地库
            data.Id = await _submitCaseProcessRepository.AddAsync(data);

            //将待推送数据写入待推送表
            WaitingPushData pushData = new()
            {
                ServiceInterface = "SubmitCaseProcess",
                Data = System.Text.Json.JsonSerializer.Serialize(data),
                Priority = 0,
                PushUrl = "submit_case_process",
                Method = HttpMethods.Post,
                SyncID = data.Id
            };
            await _waitingPushDataRepository.AddAsync(pushData);

        }

        /// <summary>
        /// 服务工单结果
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        public async Task SubmitCaseResult(OrderFlowDto dto)
        {
            var data = _mapper.Map<SubmitCaseResult>(dto);
            data.ConcactType = "40";
            data.FinishType = "1";
            data.HandleTimeLong = dto.Order.AllDuration;
            //将上报信息写入本地库
            data.Id = await _submitCaseResultRepository.AddAsync(data);

            //将待推送数据写入待推送表
            WaitingPushData pushData = new()
            {
                ServiceInterface = "SubmitCaseResult",
                Data = System.Text.Json.JsonSerializer.Serialize(data),
                Priority = 0,
                PushUrl = "submit_case_result",
                Method = HttpMethods.Post,
                SyncID = data.Id
            };
            await _waitingPushDataRepository.AddAsync(pushData);

            //判断如果是110过来的数据，就组装数据
            //组装110
            if (dto.Order.Source == ESource.Police110)
            {
                await InitPoliceSendChainDealDs(dto);
            }
        }

        /// <summary>
        /// 服务工单拓展信息
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        public async Task SubmitCaseExtends(OrderDto dto)
        {
            var orderExtension = dto.OrderExtension;
            if (orderExtension is null)
                return;

            //工单类型
            string formType = orderExtension.OrderTypeCode;

            //扩展主表信息
            ReceiveCaseExtends receiveCaseExtends = new()
            {
                CaseSerial = dto.ProvinceNo,
                FormType = formType,
                SyncState = "0",
                Direction = "1"
            };

            //将上报信息写入本地库  
            var id = await _receiveCaseExtendsRepository.AddAsync(receiveCaseExtends);

            //处理为统一的市场监管表单
            if (formType == "scjgjts" || formType == "scjgjjb")
                formType = "scjgj";

            SubmitCaseExtendsInfo submitCaseExtendsInfo = new()
            {
                CaseSerial = dto.ProvinceNo,
                FormType = formType
            };

            //处理扩展信息
            switch (formType.ToLower())
            {
                case "yl"://医疗表单
                    //转换数据
                    var dtoyl = _mapper.Map<FormMedical>(orderExtension);
                    dtoyl.RCEId = id;
                    //添加数据
                    await _formMedicalRepository.AddAsync(dtoyl);
                    submitCaseExtendsInfo.FormMedical = _mapper.Map<FormMedicalInfo>(dtoyl);
                    break;
                case "zwfw"://四川政务服务网技术工单
                    //转换数据
                    var dtozwfw = _mapper.Map<FormNetWorktec>(orderExtension);
                    dtozwfw.RCEId = id;
                    //添加数据
                    await _formNetWorktecRepository.AddAsync(dtozwfw);
                    submitCaseExtendsInfo.FormNetWorktec = _mapper.Map<FormNetWorktecInfo>(dtozwfw);
                    break;
                case "th"://电视购物及商铺购买退换货工单
                    //转换数据
                    var dtoth = _mapper.Map<FormReturnexChange>(orderExtension);
                    dtoth.RCEId = id;
                    //添加数据
                    await _formReturnexChangeRepository.AddAsync(dtoth);
                    submitCaseExtendsInfo.FormReturnexChange = _mapper.Map<FormReturnexChangeInfo>(dtoth);
                    break;
                case "gsgl"://高速公路工单
                    //转换数据
                    var dtogsgl = _mapper.Map<FormExpressWay>(orderExtension);
                    dtogsgl.RCEId = id;
                    //添加数据
                    await _formExpressWayRepository.AddAsync(dtogsgl);
                    submitCaseExtendsInfo.FormExpressWay = _mapper.Map<FormExpressWayInfo>(dtogsgl);
                    break;
                case "xjgg"://电视台虚假广告工单
                    //转换数据
                    var dtoxjgg = _mapper.Map<FormShamPub>(orderExtension);
                    dtoxjgg.RCEId = id;
                    //添加数据
                    await _formShamPubRepository.AddAsync(dtoxjgg);
                    submitCaseExtendsInfo.FormShamPub = _mapper.Map<FormShamPubInfo>(dtoxjgg);
                    break;
                case "swfwsq"://12366热线诉求交办
                    //转换数据
                    var dtoswfwsq = _mapper.Map<FormTaxationComplaint>(orderExtension);
                    dtoswfwsq.RCEId = id;
                    //添加数据
                    await _formTaxationComplaintRepository.AddAsync(dtoswfwsq);
                    submitCaseExtendsInfo.FormTaxationComplaint = _mapper.Map<FormTaxationComplaintInfo>(dtoswfwsq);
                    break;
                case "swfwzx"://12366热线咨询交办
                    //转换数据
                    var dtoswfwzx = _mapper.Map<FormTaxationConsulting>(orderExtension);
                    dtoswfwzx.RCEId = id;
                    //添加数据
                    await _formTaxationConsultingRepository.AddAsync(dtoswfwzx);
                    submitCaseExtendsInfo.FormTaxationConsulting = _mapper.Map<FormTaxationConsultingInfo>(dtoswfwzx);
                    break;
                case "jtfwjd"://12328服务监督
                    //转换数据
                    var dtojtfwjd = _mapper.Map<FormTraffic>(orderExtension);
                    dtojtfwjd.RCEId = id;
                    //添加数据
                    await _formTrafficRepository.AddAsync(dtojtfwjd);
                    submitCaseExtendsInfo.FormTraffic = _mapper.Map<FormTrafficInfo>(dtojtfwjd);
                    break;
                case "yzxf"://邮政业消费者申诉
                    //转换数据
                    var dtoyzxf = _mapper.Map<FormPost>(orderExtension);
                    dtoyzxf.RCEId = id;
                    //添加数据
                    await _formPostRepository.AddAsync(dtoyzxf);
                    submitCaseExtendsInfo.FormPost = _mapper.Map<FormPostInfo>(dtoyzxf);
                    break;
                case "hbjb"://环保举报业务
                    //转换数据
                    var dtohbjb = _mapper.Map<FormEnvironMent>(orderExtension);
                    dtohbjb.RCEId = id;
                    //添加数据
                    await _formEnvironMentRepository.AddAsync(dtohbjb);
                    submitCaseExtendsInfo.FormEnvironMent = _mapper.Map<FormEnvironMentInfo>(dtohbjb);
                    break;
                case "scjgj"://12315个性化表单
                    var dtoscjgj = _mapper.Map<FormMarket>(orderExtension);
                    //转换数据
                    switch (orderExtension.OrderTypeCode)
                    {
                        case "scjgjjb":
                            dtoscjgj.Rqsttypy = "25";
                            break;
                        case "scjgjts":
                            dtoscjgj.Rqsttypy = "20";
                            foreach (var item in orderExtension.ComplainTypes)
                                dtoscjgj.AppealContent += item.Value + ",";
                            dtoscjgj.AppealContent = dtoscjgj.AppealContent.TrimEnd(',');
                            break;
                        default:
                            break;
                    }
                    dtoscjgj.HandDepCode = dto.AcceptorOrgCode;
                    dtoscjgj.HandDep = dto.AcceptorOrgName;
                    dtoscjgj.Zxgh = dto.AcceptorStaffNo;
                    dtoscjgj.AccregperId = dto.AcceptorId;
                    dtoscjgj.AccregperName = dto.AcceptorName;
                    dtoscjgj.RegTime = Convert.ToDateTime(dto.CreationTime);
                    dtoscjgj.CmTime = dto.StartTime;
                    dtoscjgj.RCEId = id;
                    //添加数据
                    await _formMarketRepository.AddAsync(dtoscjgj);
                    submitCaseExtendsInfo.FormMarket = _mapper.Map<FormMarketInfo>(dtoscjgj);
                    break;
                default:
                    break;
            }

            //组装数据
            SubmitCaseExtendsInfoId submitCaseExtendsInfoId = new()
            {
                Id = id,
                Info = submitCaseExtendsInfo
            };

            //信息上报
            await _mediator.Publish(new SubmitCaseExtendsNotification(Newtonsoft.Json.JsonConvert.SerializeObject(submitCaseExtendsInfoId)));
        }

        /// <summary>
        /// 附件处理-----还需要根据推送过来的数据改一下赋值
        /// </summary>
        /// <param name="dto"></param>
        /// <param name="CaseSerial">工单编号或者督办编号</param>
        /// <param name="CliengGuid">附件</param>
        /// <param name="AreaCode">区域Code</param>
        /// <returns></returns>
        public async Task FileData(List<Hotline.Share.Dtos.File.FileDto> dto, string CaseSerial, string CliengGuid, string AreaCode)
        {
            if (dto != null && dto.Count > 0)
            {
                //往附件推送表中写入数据
                foreach (var item in dto)
                {
                    //将受到的数据写入本地数据库
                    GetCaseMaterialInfo materialInfo = new()
                    {
                        CaseSerial = CaseSerial,
                        // MaterialType = item.MaterialType,
                        CliengGuid = CliengGuid,
                        AreaCode = AreaCode,
                        FileName = item.Name,
                        FileSize = 0,
                        Key = item.Key,
                        Type = item.Type,
                        Additions = item.Additions,
                        Direction = "1",
                        SyncState = "0"
                    };

                    //材料类型
                    switch (item.Classify)
                    {
                        case "1":
                            materialInfo.MaterialType = "10";
                            break;
                        case "2":
                            materialInfo.MaterialType = "20";
                            break;
                        case "3":
                            materialInfo.MaterialType = "30";
                            break;
                        case "4":
                            materialInfo.MaterialType = "40";
                            break;
                        case "5":
                            materialInfo.MaterialType = "50";
                            break;
                        case "6":
                            materialInfo.MaterialType = "60";
                            break;
                        default:
                            break;
                    }

                    //将数据写入本地
                    materialInfo.Id = await _getCaseMaterialInfoRepository.AddAsync(materialInfo);
                    if (!string.IsNullOrEmpty(materialInfo.Id))
                    {
                        //写入待发表
                        WaitingPushData pushData = new()
                        {
                            ServiceInterface = "GetCaseMaterialInfo",
                            Data = System.Text.Json.JsonSerializer.Serialize(materialInfo),
                            Priority = 0,
                            PushUrl = "get_case_material_info",
                            Method = HttpMethods.Post,
                            SyncID = materialInfo.Id
                        };
                        await _waitingPushDataRepository.AddAsync(pushData);
                    }
                }
            }
        }

        #region 私有方法-往第三方推送数据

        #region 组装110数据
        /// <summary>
        /// 组装110数据，12345警情工单推送到110
        /// </summary>
        /// <param name="orderDto"></param>
        /// <returns></returns>
        private async Task InitPoliceSendChainAlarmDs(OrderDto orderDto)
        {
            PoliceSendChainAlarmDs policeSend = new()
            {
                SerialNumber = orderDto.ExternalId,
                AlarmReceiptNumber = orderDto.ExternalId,
                RegisterNo = orderDto.AcceptorStaffNo,
                CallPoliceNumber = orderDto.FromPhone,
                CallPoliceName = orderDto.FromName,
                PhoneNumber = orderDto.Contact,
                CallPoliceContent = orderDto.Content,
                PoliceTypeCode = "",
                PoliceTypeName = "",
                JurisdictionalUnitCode = "511500000000",
                JurisdictionalUnitName = "宜宾市公安局",
                JurisdictionalUnitNumber = "0831110",
                AlarmReceivingUnitCode = "",
                AlarmReceivingUnitName = "",
                CallPoliceTime = Convert.ToDateTime(orderDto.CreationTime),
                PushTime = DateTime.Now,
                AlarmReceptionType = "0",
                AreaCode = orderDto.AreaCode,
                CallPoliceAddress = orderDto.FullAddress,
                OrderId = orderDto.Id
            };

            if (string.IsNullOrEmpty(policeSend.AlarmReceiptNumber))
            {
                policeSend.AlarmReceiptNumber = orderDto.No;
                policeSend.SerialNumber = orderDto.No;
            }
            //查询是否有此工单，如果没有新增此工单
            var data = await _policeSendChainAlarmDsRepository.GetAsync(p => p.OrderId == orderDto.Id);
            if (data == null)
                await _policeSendChainAlarmDsRepository.AddAsync(policeSend);
        }

        /// <summary>
        /// 110的非警情工单获取办理信息
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        private async Task InitPoliceSendChainDealDs(OrderFlowDto dto)
        {
            var data = await _policeSendChainDealDsRepository.GetAsync(p => p.OrderId == dto.Order.Id && p.DisposalType == (int)EDisposalType.OrderFiled);
            if (data == null)
            {
                data = new()
                {
                    AlarmReceiptNumber = dto.Order.ExternalId,
                    //FeedbackTime = dto.WorkflowTrace.HandleTime,
                    //DisposalSituation = dto.WorkflowTrace.Opinion,
                    //ResultDescription = dto.WorkflowTrace.Opinion,
                    //FeedbackPersonNumber = dto.WorkflowTrace.HandlerId,
                    //FeedbackPersonName = dto.WorkflowTrace.HandlerName,
                    //FeedbackUnitCode = dto.WorkflowTrace.HandlerOrgId,
                    //FeedbackUnitName = dto.WorkflowTrace.HandlerOrgName,
                    FeedbackTime = dto.Order.ActualHandleTime,
                    DisposalSituation = dto.Order.ActualOpinion,
                    ResultDescription = dto.Order.ActualOpinion,
                    FeedbackPersonNumber = dto.Order.ActualHandlerId,
                    FeedbackPersonName = dto.Order.ActualHandlerName,
                    FeedbackUnitCode = dto.Order.ActualHandleOrgCode,
                    FeedbackUnitName = dto.Order.ActualHandleOrgName,
                    WarehousingTime = DateTime.Now,
                    DisposalType = 1,
                    OrderId = dto.Order.Id
                };
                await _policeSendChainDealDsRepository.AddAsync(data);
            }
            else
            {
                data.AlarmReceiptNumber = dto.Order.ExternalId;
                //data.FeedbackTime = dto.WorkflowTrace.HandleTime;
                //data.DisposalSituation = dto.WorkflowTrace.Opinion;
                //data.ResultDescription = dto.WorkflowTrace.Opinion;
                //data.FeedbackPersonNumber = dto.WorkflowTrace.HandlerId;
                //data.FeedbackPersonName = dto.WorkflowTrace.HandlerName;
                //data.FeedbackUnitCode = dto.WorkflowTrace.HandlerOrgId;
                //data.FeedbackUnitName = dto.WorkflowTrace.HandlerOrgName;
                data.FeedbackTime = dto.Order.ActualHandleTime;
                data.DisposalSituation = dto.Order.ActualOpinion;
                data.ResultDescription = dto.Order.ActualOpinion;
                data.FeedbackPersonNumber = dto.Order.ActualHandlerId;
                data.FeedbackPersonName = dto.Order.ActualHandlerName;
                data.FeedbackUnitCode = dto.Order.ActualHandleOrgCode;
                data.FeedbackUnitName = dto.Order.ActualHandleOrgName;
                data.WarehousingTime = DateTime.Now;
                await _policeSendChainDealDsRepository.UpdateAsync(data);
            }
        }

        #endregion

        #region 宜宾泸州市州数据提交
        /// <summary>
        /// 宜宾泸州市州数据提交
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        private async Task InitCityDataYB(OrderDto dto)
        {
            var cityDataSend = _mapper.Map<CityDataSend>(dto);
            cityDataSend.ServerName = string.IsNullOrEmpty(cityDataSend.ServerName) ? "市民" : cityDataSend.ServerName;

            //写入本地数据库
            cityDataSend.Id = await _cityDataSendRepository.AddAsync(cityDataSend);

            //信息上报
            await _mediator.Publish(new InitCityDataYBNotification(cityDataSend));
        }
        #endregion

        #region 宜宾企业专班数据提交
        /// <summary>
        /// 企业专班数据提交
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        private async Task InitEnterpriseData(OrderDto dto)
        {
            var enterpriseData = _mapper.Map<DataWorkOrderSend>(dto);

            //附件处理
            List<ReplyFiles> replyFiles = new List<ReplyFiles>();
            if (dto.Files != null)
            {
                foreach (var item in dto.Files)
                {
                    ReplyFiles files = new ReplyFiles
                    {
                        Filename = item.Name,
                        Fileformat = item.Classify
                    };
                    replyFiles.Add(files);
                }
                enterpriseData.ReplyFiles = replyFiles;
            }

            //添加本地数据
            enterpriseData.Id = await _dataWorkOrderSendRepository.AddAsync(enterpriseData);

            //信息上报
            await _mediator.Publish(new EnterpriseSendNotification(enterpriseData));
        }
        #endregion

        #region 往省上派单
        /// <summary>
        /// 往省上派单
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        private async Task SendCaseInfo(OrderDto dto)
        {
            //先上传拓展信息
            await SubmitCaseExtends(dto);

            //在处理工单信息
            var sendCaseInfo = _mapper.Map<SendCaseInfo>(dto);

            #region 处理数据
            //处理性别
            switch (dto.FromGender)
            {
                case EGender.Female:
                    sendCaseInfo.AppLicantSex = "0";
                    break;
                case EGender.Male:
                    sendCaseInfo.AppLicantSex = "1";
                    break;
                case EGender.Unknown:
                    sendCaseInfo.AppLicantSex = "2";
                    break;
                default:
                    sendCaseInfo.AppLicantSex = "2";
                    break;
            }

            //处理证件类型
            sendCaseInfo.CertifiCateType = dto.LicenceTypeCode switch
            {
                "10" => "10",
                "40" => "20",
                "55" => "30",
                "57" => "40",
                _ => "50",
            };

            //处理紧急程度
            sendCaseInfo.CaseIsUrgent = dto.EmergencyLevel switch
            {
                EEmergencyLevel.QuiteEmergency => "10",
                EEmergencyLevel.Emergency => "20",
                _ => "30",
            };

            //处理诉求类型
            switch (sendCaseInfo.CaseType)
            {
                case "10":
                case "15":
                case "20":
                case "25":
                case "30":
                case "35":
                    break;
                default:
                    sendCaseInfo.CaseType = "40";
                    break;
            }
            #endregion

            sendCaseInfo.Id = await _sendCaseInfoRepository.AddAsync(sendCaseInfo);

            await _mediator.Publish(new SendCaseInfoNotification(sendCaseInfo));
        }
        #endregion

        #endregion

    }
}
