﻿using DotNetCore.CAP;
using Hotline.Api.Sdk;
using Hotline.Share.Dtos.Order;
using MapsterMapper;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;
using Sharing.DataExchange.Dtos;
using Sharing.DataExchange.Extensions;
using Sharing.WebCore;
using XF.Domain.Repository;

namespace Sharing.DataExchange.Controllers
{
    /// <summary>
    /// 
    /// </summary>
    public class CityHandOverYBController : BaseController
    {
        private readonly IMapper _mapper;
        private readonly IRepository<CityDataReceive> _cityDataReceiveRepository;
        private readonly IChannelConfigurationManager _channelConfigurationManager;
        private readonly IHotlineClient _hotlineClient;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="mapper"></param>
        /// <param name="cityDataReceiveRepository"></param>
        /// <param name="channelConfigurationManager"></param>
        /// <param name="hotlineClient"></param>
        public CityHandOverYBController(IMapper mapper, IRepository<CityDataReceive> cityDataReceiveRepository
            , IChannelConfigurationManager channelConfigurationManager, IHotlineClient hotlineClient)
        {
            _mapper = mapper;
            _cityDataReceiveRepository = cityDataReceiveRepository;
            _channelConfigurationManager = channelConfigurationManager;
            _hotlineClient = hotlineClient;
        }

        /// <summary>
        /// 宜宾泸州数据互换
        /// </summary>
        /// <param name="cityDataReceiveDto">宜宾泸州数据互换</param>
        /// <returns></returns>
        [HttpPost("city_hand_data")]
        [AllowAnonymous]
        public async Task<DeReponse> CityHandData([FromBody] CityDataReceiveDto cityDataReceiveDto)
        {
            // 验证
            if (cityDataReceiveDto is null)
                return DeReponse.Failed(description: "数据解析失败");

            //验证数据
            string strResult = cityDataReceiveDto.Validate();
            if (!string.IsNullOrEmpty(strResult))
                return DeReponse.Failed(description: strResult);

            var cityHandOver = _channelConfigurationManager.GetConfigurationCityHandOver();
            //验证MD5
            strResult = CComm.Verification(cityDataReceiveDto.Code, cityDataReceiveDto.Source + cityHandOver.SecretKey);
            if (!string.IsNullOrEmpty(strResult))
                return DeReponse.Failed("-900", strResult);

            //转换数据
            var dto = _mapper.Map<CityDataReceive>(cityDataReceiveDto);
            //添加数据
            var id = await _cityDataReceiveRepository.AddAsync(dto, HttpContext.RequestAborted);

            if (!string.IsNullOrEmpty(id))
            {
                AddOrderDto data = new()
                {
                    Title = cityDataReceiveDto.Title,
                    ExternalId = cityDataReceiveDto.FSHCode,
                    AcceptType = cityDataReceiveDto.PurTypeName,
                    HotspotSpliceName = cityDataReceiveDto.ConTypeName,
                    FromName = cityDataReceiveDto.LinkName,
                    Contact = cityDataReceiveDto.Mobile,
                    Address = cityDataReceiveDto.Address,
                    Content = cityDataReceiveDto.Content,
                    Source = Hotline.Share.Enums.Order.ESource.CityDataExchangeLz,
                    FromGender = cityDataReceiveDto.Gender switch
                    {
                        "1" => Hotline.Share.Enums.Order.EGender.Male,
                        "2" => Hotline.Share.Enums.Order.EGender.Female,
                        _ => Hotline.Share.Enums.Order.EGender.Unknown,
                    }
                };
                //调用工单创建接口
                var result = await _hotlineClient.AddOrderAsync(data, default);
                if (result.IsSuccess)
                {
                    dto.Id = id;
                    dto.OrderId = result.Result.Id;
                    await _cityDataReceiveRepository.UpdateAsync(dto, HttpContext.RequestAborted);
                    return DeReponse.Success(cityDataReceiveDto.FSHCode, "您已成功提交数据！");
                }
                else
                    return DeReponse.Failed(description: result.Error);

            }
            else
                return DeReponse.Failed(description: "接口调用失败！");
        }

    }
}
