﻿using MediatR;
using Newtonsoft.Json;
using Sharing.DataExchange.Dtos;
using Sharing.DataExchange.Extensions;
using Sharing.Notifications.DataExchange;
using System.Net;
using XF.Domain.Repository;

namespace Sharing.DataExchange.Handlers
{
    /// <summary>
    /// 市州互转
    /// </summary>
    public class InitCityDataYBHandler : INotificationHandler<InitCityDataYBNotification>
    {
        private readonly IHttpClientFactory _httpClientFactory;
        private readonly IRepository<CityDataSend> _cityDataSendRepository;
        private readonly IChannelConfigurationManager _channelConfigurationManager;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="httpClientFactory"></param>
        /// <param name="cityDataSendRepository"></param>
        /// <param name="channelConfigurationManager"></param>
        public InitCityDataYBHandler(IHttpClientFactory httpClientFactory, IRepository<CityDataSend> cityDataSendRepository, IChannelConfigurationManager channelConfigurationManager)
        {
            _httpClientFactory = httpClientFactory;
            _cityDataSendRepository = cityDataSendRepository;
            _channelConfigurationManager = channelConfigurationManager;
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="notification"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        public async Task Handle(InitCityDataYBNotification notification, CancellationToken cancellationToken)
        {
            var order = notification.Data;

            #region 提交请求
            var cityHandOver = _channelConfigurationManager.GetConfigurationCityHandOver();
            order.Source = string.IsNullOrEmpty(order.Source) ? cityHandOver.SendCityName : order.Source;
            string secretKey = CComm.GetMD5(order.Source + cityHandOver.SecretKey);

            Dictionary<string, string> dicParam = new()
            {
                { "Code", secretKey },
                { "FSHCode", order.FSHCode },
                { "ServerName", order.ServerName},
                { "PurTypeName",order.PurTypeName },
                { "ConTypeName", order.ConTypeName},
                { "Title", order.Title},
                { "LinkName", order.LinkName},
                { "Gender",order.Gender},
                { "Mobile", order.Mobile},
                { "Mail",order.Mail },
                { "Address", order.Address },
                { "Content", order.Content},
                { "Source", order.Source }
            };
            // 将参数转化为HttpContent
            HttpContent content = new FormUrlEncodedContent(dicParam);
            string result = "";
            try
            {
                using (var client = _httpClientFactory.CreateClient())
                using (var response = await client.PostAsync(cityHandOver.BaseUrl + cityHandOver.UrlAddress, content))
                {
                    if (response.StatusCode == HttpStatusCode.OK)
                    {
                        result = await response.Content.ReadAsStringAsync();
                    }
                }
            }
            catch (Exception)
            {

            }

            #endregion

            //处理返回信息
            if (!string.IsNullOrEmpty(result))
            {
                var responseData = JsonConvert.DeserializeObject<ResponseDto>(result);
                if (responseData != null)
                {
                    if (responseData.Code == "1")
                        notification.Data.SyncState = "1";
                    else
                        notification.Data.SyncState = "2";

                    notification.Data.ReturnResult = result;
                    await _cityDataSendRepository.UpdateAsync(notification.Data);
                }
            }
        }
    }
}
