﻿using MapsterMapper;
using MediatR;
using Sharing.Enterprise.Dtos.Send;
using Sharing.Notifications.Enterprise;
using XF.Domain.Repository;

namespace Sharing.Enterprise.Handlers
{
    /// <summary>
    /// 企业撤销
    /// </summary>
    public class EnterpriseCancelHandler : INotificationHandler<EnterpriseCancelWorkOrderNotification>
    {
        private readonly IChannelConfigurationManager _channelConfigurationManager;
        private readonly EnterprisePusherProvider _pusherProvider;
        private readonly IMapper _mapper;
        private readonly IRepository<DataWorkOrderCancel> _dataWorkOrderCancelRepository;

        /// <summary>
        /// 注入
        /// </summary>
        /// <param name="channelConfigurationManager"></param>
        /// <param name="pusherProvider"></param>
        /// <param name="mapper"></param>
        /// <param name="dataWorkOrderCancelRepository"></param>
        public EnterpriseCancelHandler(IChannelConfigurationManager channelConfigurationManager, EnterprisePusherProvider pusherProvider
            , IMapper mapper, IRepository<DataWorkOrderCancel> dataWorkOrderCancelRepository)
        {
            _channelConfigurationManager = channelConfigurationManager;
            _pusherProvider = pusherProvider;
            _mapper = mapper;
            _dataWorkOrderCancelRepository = dataWorkOrderCancelRepository;
        }

        /// <summary>
        /// 企业数据撤单
        /// </summary>
        /// <param name="notification"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        public async Task Handle(EnterpriseCancelWorkOrderNotification notification, CancellationToken cancellationToken)
        {
            var pusher = _pusherProvider.CreatePusher(_channelConfigurationManager);

            var cancelWorkOrder = _mapper.Map<CancelWorkOrder>(notification.Data);
            var request = new CancelWorkOrderRequest();
            request.SetData(cancelWorkOrder);
            var response = await pusher.PushWorkOrderCancelAsync(request, cancellationToken);

            //如果推送成功修改数据状态
            if (response != null)
            {
                if (response.code == 200 && response.success)
                    notification.Data.SyncState = "1";
                else
                    notification.Data.SyncState = "2";

                notification.Data.ReturnResult = Newtonsoft.Json.JsonConvert.SerializeObject(response);
                await _dataWorkOrderCancelRepository.UpdateAsync(notification.Data);
            }
        }
    }
}
