﻿using MapsterMapper;
using MediatR;
using Sharing.Notifications.HuiJu;
using Sharing.Orders;
using Sharing.Province.Dtos.HuiJu.Send;
using Sharing.Province.HuiJu.Send;
using XF.Domain.Repository;

namespace Sharing.Province.Handlers.HuiJu
{
    /// <summary>
    /// 服务工单受理
    /// </summary>
    public class OrderCreatedHandler : INotificationHandler<OrderCreatedNotification>
    {
        private readonly IChannelConfigurationManager _channelConfigurationManager;
        private readonly PusherProvider _pusherProvider;
        private readonly IMapper _mapper;
        private readonly IRepository<SubmitCaseInfo> _submitCaseInfoRepository;
        private readonly IDataOrderRepository _dataOrderRepository;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="channelConfigurationManager"></param>
        /// <param name="pusherProvider"></param>
        /// <param name="mapper"></param>
        /// <param name="submitCaseInfoRepository"></param>
        /// <param name="dataOrderRepository"></param>
        public OrderCreatedHandler(IChannelConfigurationManager channelConfigurationManager, PusherProvider pusherProvider, IMapper mapper
            , IRepository<SubmitCaseInfo> submitCaseInfoRepository, IDataOrderRepository dataOrderRepository)
        {
            _channelConfigurationManager = channelConfigurationManager;
            _pusherProvider = pusherProvider;
            _mapper = mapper;
            _submitCaseInfoRepository = submitCaseInfoRepository;
            _dataOrderRepository = dataOrderRepository;
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="notification"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        public async Task Handle(OrderCreatedNotification notification, CancellationToken cancellationToken)
        {
            var order = notification.DataOrder;
            var pusher = _pusherProvider.CreatePusher(_channelConfigurationManager);

            var dataReceive = _mapper.Map<CaseInfo>(order);
            var request = new SubmitCaseInfoRequest();

            request.ForeachClass(dataReceive);

            var data = new SubmitCaseInfoData
            {
                CaseInfos = new List<CaseInfo>
                {
                    dataReceive
                }
            };

            request.SetData(data);

            var response = await pusher.PushOrderCreatedAsync(request, cancellationToken);

            //如果推送成功修改数据状态
            if (response != null)
            {
                if (response.Code == "1")
                    notification.DataOrder.SyncState = "1";
                else
                    notification.DataOrder.SyncState = "2";

                notification.DataOrder.ReturnResult = Newtonsoft.Json.JsonConvert.SerializeObject(response);
                await _submitCaseInfoRepository.UpdateAsync(notification.DataOrder);

              var dataOrder=  await _dataOrderRepository.GetAsync(p => p.OrderId == order.OrderID);
                if (dataOrder==null)
                {
                    dataOrder = new()
                    {
                        OrderId=order.OrderID,
                        OrderNo=order.No,
                        ProvinceNo=order.CaseSerial,
                        CaseDate=order.CaseDate,
                        FirstSyncProvinceTime=DateTime.Now,
                        SyncInterval=0,
                        IsTimelyUpload=true,
                        CaseSource = order.CaseSource,
                        ExpiredTime=order.TfdBackTimeBf,
                        CaseType=order.CaseType,
                        AllDuration=0,
                      //  IsProvince=
                    };
                    if (true)
                    {

                    }
                    await _dataOrderRepository.AddAsync(dataOrder);
                }
                else
                {
                    //修改
                }
               
            }
        }
    }
}