﻿using MapsterMapper;
using MediatR;
using Sharing.Notifications.HuiJu;
using Sharing.Orders;
using Sharing.Province.Dtos;
using Sharing.Province.Dtos.HuiJu.Send;
using Sharing.Province.HuiJu.Send;
using Sharing.Province.Other;
using XF.Domain.Repository;

namespace Sharing.Province.Handlers.HuiJu
{
    /// <summary>
    /// 
    /// </summary>
    public class SubmitCaseResultHandler : INotificationHandler<SubmitCaseResultNotification>
    {
        private readonly IChannelConfigurationManager _channelConfigurationManager;
        private readonly PusherProvider _pusherProvider;
        private readonly IMapper _mapper;
        private readonly IRepository<SubmitCaseResult> _submitCaseResultRepository;
        private readonly IWaitingPushDataRepository _waitingPushDataRepository;
        private readonly IDataOrderRepository _dataOrderRepository;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="channelConfigurationManager"></param>
        /// <param name="pusherProvider"></param>
        /// <param name="mapper"></param>
        /// <param name="submitCaseResultRepository"></param>
        /// <param name="waitingPushDataRepository"></param>
        /// <param name="dataOrderRepository"></param>
        public SubmitCaseResultHandler(IChannelConfigurationManager channelConfigurationManager, PusherProvider pusherProvider
            , IMapper mapper, IRepository<SubmitCaseResult> submitCaseResultRepository, IWaitingPushDataRepository waitingPushDataRepository
            , IDataOrderRepository dataOrderRepository)
        {
            _channelConfigurationManager = channelConfigurationManager;
            _pusherProvider = pusherProvider;
            _mapper = mapper;
            _submitCaseResultRepository = submitCaseResultRepository;
            _waitingPushDataRepository = waitingPushDataRepository;
            _dataOrderRepository = dataOrderRepository;
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="notification"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        public async Task Handle(SubmitCaseResultNotification notification, CancellationToken cancellationToken)
        {
            var pusher = _pusherProvider.CreatePusher(_channelConfigurationManager);

            var dataReceive = _mapper.Map<List<CaseResult>>(notification.DataOrder);

            var request = new SubmitCaseResultRequest();

            foreach (var item in dataReceive)
            {
                request.ForeachClass(dataReceive);
                var dataOrder = await _dataOrderRepository.GetAsync(p => p.ProvinceNo == item.CaseSerial);
                if (dataOrder != null)
                {
                    if (dataOrder.FirstSyncResultTime == null || dataOrder.FirstSyncResultTime is null)
                    {
                        dataOrder.FirstSyncResultTime = DateTime.Now;
                    }
                    dataOrder.NewSyncResultTime = DateTime.Now;
                    dataOrder.NewSyncResultReplyTime = item.FinishTime;
                    dataOrder.AllDuration = item.HandleTimeLong * 60;

                    await _dataOrderRepository.UpdateAsync(dataOrder);
                }
            }
            var data = new SubmitCaseResultData
            {
                CaseResults = dataReceive
            };
            request.SetData(data);

            var response = await pusher.PushSubmitCaseResultAsync(request, cancellationToken);

            //如果推送成功修改数据状态
            if (response != null)
            {
                List<ErrorInfo> list = new();
                if (response.custom != null && response.custom.errorObjs != null && response.custom.errorObjs.Count > 0)
                {
                    list = response.custom.errorObjs;
                }
                foreach (var item in notification.DataOrder)
                {
                    if (list != null && list.Count > 0)
                    {
                        if (list.Find(p => p.caseserial == item.CaseSerial) != null)
                            item.SyncState = "2";
                        else
                            item.SyncState = "1";
                    }
                    else
                        item.SyncState = "1";

                    await _submitCaseResultRepository.UpdateAsync(item);
                    await _waitingPushDataRepository.RemoveAsync(p => p.SyncID == item.Id);
                }
                //if (response.Code == "1")
                //    notification.DataOrder.SyncState = "1";
                //else
                //    notification.DataOrder.SyncState = "2";

                //notification.DataOrder.ReturnResult = Newtonsoft.Json.JsonConvert.SerializeObject(response);
                //await _submitCaseResultRepository.UpdateAsync(notification.DataOrder);
            }
        }
    }
}
