﻿using MapsterMapper;
using MediatR;
using Sharing.Notifications.HuiJu;
using Sharing.Orders;
using Sharing.Province.Dtos;
using Sharing.Province.Dtos.HuiJu.Send;
using Sharing.Province.HuiJu.Send;
using Sharing.Province.Other;
using XF.Domain.Repository;

namespace Sharing.Province.Handlers.HuiJu
{
    /// <summary>
    /// 服务工单回访评价
    /// </summary>
    public class SubmitVisitInfoHandler : INotificationHandler<SubmitVisitInfoNotification>
    {
        private readonly IChannelConfigurationManager _channelConfigurationManager;
        private readonly PusherProvider _pusherProvider;
        private readonly IMapper _mapper;
        private readonly IRepository<SubmitVisitInfo> _submitVisitInfoRepository;
        private readonly IWaitingPushDataRepository _waitingPushDataRepository;
        private readonly IDataOrderRepository _dataOrderRepository;

       /// <summary>
       /// 
       /// </summary>
       /// <param name="channelConfigurationManager"></param>
       /// <param name="pusherProvider"></param>
       /// <param name="mapper"></param>
       /// <param name="submitVisitInfoRepository"></param>
       /// <param name="waitingPushDataRepository"></param>
       /// <param name="dataOrderRepository"></param>
        public SubmitVisitInfoHandler(IChannelConfigurationManager channelConfigurationManager, PusherProvider pusherProvider, IMapper mapper
            , IRepository<SubmitVisitInfo> submitVisitInfoRepository, IWaitingPushDataRepository waitingPushDataRepository
            , IDataOrderRepository dataOrderRepository)
        {
            _channelConfigurationManager = channelConfigurationManager;
            _pusherProvider = pusherProvider;
            _mapper = mapper;
            _submitVisitInfoRepository = submitVisitInfoRepository;
            _waitingPushDataRepository = waitingPushDataRepository;
            _dataOrderRepository = dataOrderRepository;
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="notification"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        public async Task Handle(SubmitVisitInfoNotification notification, CancellationToken cancellationToken)
        {
            var pusher = _pusherProvider.CreatePusher(_channelConfigurationManager);

            var dataReceive = _mapper.Map<List<VisitInfo>>(notification.DataOrder);

            var request = new SubmitVisitInfoRequest();
            foreach (var item in dataReceive)
            {
                request.ForeachClass(item);
                var dataOrder = await _dataOrderRepository.GetAsync(p => p.ProvinceNo == item.CaseSerial);
                if (dataOrder != null)
                {
                    if (dataOrder.FirstSyncVisitTime == null || dataOrder.FirstSyncVisitTime is null)
                    {
                        dataOrder.FirstSyncVisitTime = DateTime.Now;
                    }
                    dataOrder.NewSyncVisitTime = item.VisitTime;
                    dataOrder.NewSyncVisitReplyTime = DateTime.Now;
                    dataOrder.FirstSatisfaction = item.FirstSatisfaction;
                    dataOrder.NewSatisfaction = item.SubjectResultSatify;
                    await _dataOrderRepository.UpdateAsync(dataOrder);
                }
            }
            var data = new SubmitVisitInfoData
            {
                VisitInfos = dataReceive
            };
            request.SetData(data);

            var response = await pusher.PushSubmitVisitInfoAsync(request, cancellationToken);

            //如果推送成功修改数据状态
            if (response != null)
            {
                List<ErrorInfo> list = new();
                if (response.custom != null && response.custom.errorObjs != null && response.custom.errorObjs.Count > 0)
                {
                    list = response.custom.errorObjs;
                }
                foreach (var item in notification.DataOrder)
                {
                    if (list != null && list.Count > 0)
                    {
                        if (list.Find(p => p.caseserial == item.CaseSerial) != null)
                            item.SyncState = "2";
                        else
                            item.SyncState = "1";
                    }
                    else
                        item.SyncState = "1";

                    await _submitVisitInfoRepository.UpdateAsync(item);
                    await _waitingPushDataRepository.RemoveAsync(p => p.SyncID == item.Id);

                }
                //if (response.Code == "1")
                //    notification.DataOrder.SyncState = "1";
                //else
                //    notification.DataOrder.SyncState = "2";

                //notification.DataOrder.ReturnResult = Newtonsoft.Json.JsonConvert.SerializeObject(response);
                //await _submitVisitInfoRepository.UpdateAsync(notification.DataOrder);
            }
        }
    }
}
