﻿using Hotline.Api.Sdk;
using MapsterMapper;
using MediatR;
using Sharing.Notifications.XieTong;
using Sharing.Province.Dtos.XieTong.Receive;
using Sharing.Province.XieTong.Receive;
using XF.Domain.Repository;

namespace Sharing.Province.Handlers.XieTong
{
    /// <summary>
    /// 
    /// </summary>
    public class GetCaseDistrecordSendHandler : INotificationHandler<GetCaseDistrecordSendNotification>
    {
        private readonly IChannelConfigurationManager _channelConfigurationManager;
        private readonly PusherProvider _pusherProvider;
        private readonly IMapper _mapper;
        private readonly IRepository<GetCaseDistrecordSend> _getCaseDistrecordSendRepository;
        private readonly IHotlineClient _hotlineClient;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="channelConfigurationManager"></param>
        /// <param name="pusherProvider"></param>
        /// <param name="mapper"></param>
        /// <param name="getCaseDistrecordSendRepository"></param>
        /// <param name="hotlineClient"></param>
        public GetCaseDistrecordSendHandler(IChannelConfigurationManager channelConfigurationManager, PusherProvider pusherProvider, IMapper mapper
            , IRepository<GetCaseDistrecordSend> getCaseDistrecordSendRepository, IHotlineClient hotlineClient)
        {
            _channelConfigurationManager = channelConfigurationManager;
            _pusherProvider = pusherProvider;
            _mapper = mapper;
            _getCaseDistrecordSendRepository = getCaseDistrecordSendRepository;
            _hotlineClient = hotlineClient;
        }

        /// <summary>
        /// 服务工单上报12315过程信息查询
        /// </summary>
        /// <param name="notification"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        public async Task Handle(GetCaseDistrecordSendNotification notification, CancellationToken cancellationToken = default)
        {
            var pusher = _pusherProvider.CreatePusher(_channelConfigurationManager);

            var request = new GetCaseDistrecordSendRequest();

            request.SetData(new GetCaseDistrecordSendInfo()
            {
                CaseSerial = notification.Data
            });

            var response = await pusher.PushGetCaseDistrecordSendAsync(request, cancellationToken);

            if (response is null || response.status is null || response.custom is null)
                return;

            if (response.status.code != "1")
                return;

            //这里处理业务
            if (response.custom.STEP_List != null && response.custom.STEP_List.Count > 0)
            {
                //遍历返回的数据
                foreach (var item in response.custom.STEP_List)
                {
                    //检测当前数据是否存在，如果存在不处理，不存在新增到数据库并推送到业务系统
                    if (!await _getCaseDistrecordSendRepository.AnyAsync(p => p.CaseSerial == response.custom.CASE_SERIAL && p.RowGuid == item.RowGuid))
                    {
                        var tempData = _mapper.Map<GetCaseDistrecordSend>(item);
                        await _getCaseDistrecordSendRepository.AddAsync(tempData);

                        //这里调用业务接口，推送办理数据
                        //  _hotlineClient.AddOrderAsync();
                    }
                }
            }
        }
    }
}
